@@ -2,8 +2,9 @@ package Firefox::Marionette::Element;
 
 use strict;
 use warnings;
+use parent qw(Firefox::Marionette::LocalObject);
 
-our $VERSION = '1.46';
+our $VERSION = '1.47';
 
 sub IDENTIFIER { return 'element-6066-11e4-a52e-4f735466cecf' }
 
@@ -16,23 +17,7 @@ sub new {
     else {
         delete $parameters{ELEMENT};
     }
-    my $element = bless {
-        browser => $browser,
-        %parameters
-    }, $class;
-    return $element;
-}
-
-sub TO_JSON {
-    my ($self) = @_;
-    my $json = {};
-    if ( $self->{_old_protocols_key} ) {
-        $json->{ $self->{_old_protocols_key} } = $self->uuid();
-    }
-    else {
-        $json->{ IDENTIFIER() } = $self->uuid();
-    }
-    return $json;
+    return $class->SUPER::new( $browser, %parameters );
 }
 
 sub aria_label {
@@ -45,16 +30,6 @@ sub aria_role {
     return $self->browser()->aria_role($self);
 }
 
-sub uuid {
-    my ($self) = @_;
-    return $self->{ IDENTIFIER() };
-}
-
-sub browser {
-    my ($self) = @_;
-    return $self->{browser};
-}
-
 sub click {
     my ($self) = @_;
     return $self->browser()->click($self);
@@ -360,7 +335,7 @@ Firefox::Marionette::Element - Represents a Firefox element retrieved using the
 
 =head1 VERSION
 
-Version 1.46
+Version 1.47
 
 =head1 SYNOPSIS
 
@@ -397,10 +372,6 @@ returns the L<ARIA role|https://developer.mozilla.org/en-US/docs/Web/Accessibili
 
 accepts a scalar name a parameter.  It returns the initial value of the attribute with the supplied name. Compare with the current value returned by L<property|Firefox::Marionette::Element#property> method.
 
-=head2 browser
-
-returns the L<browser|Firefox::Marionette> connected with the L<element|Firefox::Marionette::Element>.
-
 =head2 clear
 
 clears any user supplied input from the L<element|Firefox::Marionette::Element>
