@@ -2,9 +2,9 @@ package Firefox::Marionette::Exception::InsecureCertificate;
 
 use strict;
 use warnings;
-use base qw(Firefox::Marionette::Exception::Response);
+use parent qw(Firefox::Marionette::Exception::Response);
 
-our $VERSION = '1.46';
+our $VERSION = '1.47';
 
 sub throw {
     my ( $class, $response, $parameters ) = @_;
@@ -25,7 +25,7 @@ Firefox::Marionette::Exception::InsecureCertificate - Represents a 'insecure cer
 
 =head1 VERSION
 
-Version 1.46
+Version 1.47
 
 =head1 SYNOPSIS
 
