@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use URI::URL();
 
-use base qw(Firefox::Marionette::Element);
+use parent qw(Firefox::Marionette::Element);
 
-our $VERSION = '1.46';
+our $VERSION = '1.47';
 
 sub new {
     my ( $class, $element ) = @_;
@@ -89,7 +89,7 @@ Firefox::Marionette::Image - Represents an image from the images method
 
 =head1 VERSION
 
-Version 1.46
+Version 1.47
 
 =head1 SYNOPSIS
 
