@@ -4,14 +4,14 @@ use warnings;
 use strict;
 use English qw( -no_match_vars );
 use Waterfox::Marionette::Profile();
-use base qw(Firefox::Marionette);
+use parent qw(Firefox::Marionette);
 Firefox::Marionette->import(qw(:all));
 
 our @EXPORT_OK =
   qw(BY_XPATH BY_ID BY_NAME BY_TAG BY_CLASS BY_SELECTOR BY_LINK BY_PARTIAL);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-our $VERSION = '1.46';
+our $VERSION = '1.47';
 
 sub default_binary_name {
     return 'waterfox';
@@ -54,7 +54,7 @@ Waterfox::Marionette - Automate the Waterfox browser with the Marionette protoco
 
 =head1 VERSION
 
-Version 1.46
+Version 1.47
 
 =head1 SYNOPSIS
 
